
"""Configure the repo-wide run as follows:"""

# Set necessary variables to build the config
docker_image_tag = 'sc_rnaseq_sample_level_test_5'
db_file_name = docker_image_tag

AUTH_KEY = "NWFsNXBubG5kNjo6Mnc5SjVZRlY4ejRURnNLdXMycmIwN2JoZEhvek1YcWU2bHhoYVNJTA=="

"""Step 1: What level do you want to run the error collection for?"""
run_dataset_level_validations = True
run_sample_level_validations = True

"""Step 2: What repos do you want to run the error collection for?"""
repos_for_dataset_level_validation = ["single_cell_rnaseq_omixatlas"]
repos_for_sample_level_validation = ["single_cell_rnaseq_omixatlas"]

"""Step 3: Provide schemas for the aforementioned repos as a dict with 
repo name as the key and schema dict as the value"""
schemas_for_dataset_level_validation = {"single_cell_rnaseq_omixatlas": {
    'curated_organism': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                         'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                         'filter_size': 1000, 'original_name': 'organism', 'display_name': 'Organism',
                         'description': 'Organism from which the samples were derived',
                         'is_reserved': False},
    'total_num_cells': {'type': 'integer', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                        'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                        'filter_size': 3000, 'original_name': 'total_num_cells',
                        'display_name': 'Number of Cells',
                        'description': 'Total number of cells in a dataset', 'is_reserved': False},
    'src_uri': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'kw_src_uri', 'display_name': 'Source URI',
                'description': "Unique URI derived from data file's S3 location", 'is_reserved': False},
    'curated_sampling_technique': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': True,
                                   'is_column': True, 'is_curated': True, 'is_ontology': False,
                                   'is_searchable': True, 'filter_size': 3000,
                                   'original_name': 'curated_sampling_technique',
                                   'display_name': 'Sampling Technique',
                                   'description': 'The method/procedure used for collecting samples ',
                                   'is_reserved': False},
    'total_num_samples': {'type': 'integer', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                          'is_column': True, 'is_curated': False, 'is_ontology': False,
                          'is_searchable': True, 'filter_size': 3000, 'original_name': 'total_num_samples',
                          'display_name': 'Samples', 'description': 'Total number of samples in a dataset',
                          'is_reserved': False},
    'year': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False, 'is_column': False,
             'is_curated': False, 'is_ontology': False, 'is_searchable': True, 'filter_size': 1,
             'original_name': 'year', 'display_name': 'Year',
             'description': 'Year in which the dataset was published', 'is_reserved': False},
    'curated_cell_line': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                          'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                          'filter_size': 3000, 'original_name': 'kw_cell_line', 'display_name': 'Cell Line',
                          'description': 'Cell lines from which the samples were derived for this dataset',
                          'is_reserved': False},
    'description': {'type': 'text', 'is_keyword': False, 'is_array': False, 'is_filter': False,
                    'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                    'filter_size': 1, 'original_name': 'description', 'display_name': 'Title',
                    'description': 'Description of the dataset', 'is_reserved': False},
    'data_table_name': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                        'is_column': False, 'is_curated': False, 'is_ontology': False,
                        'is_searchable': False, 'filter_size': 2000, 'original_name': 'data_table_name',
                        'display_name': 'Data-matrix table',
                        'description': 'Name of the data table associated with data file',
                        'is_reserved': True},
    'data_table_version': {'type': 'integer', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                           'is_column': False, 'is_curated': False, 'is_ontology': False,
                           'is_searchable': False, 'filter_size': 2000,
                           'original_name': 'data_table_version', 'display_name': 'Data-matrix version',
                           'description': 'Current version of the data table associated with data file',
                           'is_reserved': True},
    'timestamp_': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                   'filter_size': 2000, 'original_name': 'kw_timestamp_', 'display_name': 'Timestamp',
                   'description': 'Unix timestamp denoting time of creation for this entry',
                   'is_reserved': False},
    'file_type': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                  'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                  'filter_size': 2000, 'original_name': 'kw_file_type', 'display_name': 'File type',
                  'description': "Data file's type", 'is_reserved': False},
    'publication': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                    'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                    'filter_size': 1, 'original_name': 'publication', 'display_name': 'Publication',
                    'description': 'Link to the publication associated with the dataset. If the associated publication information is not available, then this field provides the link to the data source providing more information on the dataset.',
                    'is_reserved': False},
    'curated_single_cell_chemistry': {'type': 'text', 'is_keyword': True, 'is_array': True,
                                      'is_filter': True, 'is_column': True, 'is_curated': True,
                                      'is_ontology': False, 'is_searchable': True, 'filter_size': 3000,
                                      'original_name': 'curated_single_cell_chemistry',
                                      'display_name': 'Single cell Chemistry',
                                      'description': 'The sequencing method/platform used for sequencing the single cell genome',
                                      'is_reserved': False},
    'curated_cell_type': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                          'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                          'filter_size': 3000, 'original_name': 'kw_cell_type', 'display_name': 'Cell Type',
                          'description': 'Types of cell present in the dataset', 'is_reserved': False},
    'curated_storage_technique': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': True,
                                  'is_column': True, 'is_curated': True, 'is_ontology': False,
                                  'is_searchable': True, 'filter_size': 3000,
                                  'original_name': 'curated_storage_technique',
                                  'display_name': 'Storage Technique',
                                  'description': 'The method/technique used for preservation or storage of sample for analysis',
                                  'is_reserved': False},
    'key': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False, 'is_column': False,
            'is_curated': False, 'is_ontology': False, 'is_searchable': False, 'filter_size': 2000,
            'original_name': 'kw_key', 'display_name': 'Key',
            'description': 'Key to the data file in source package', 'is_reserved': False},
    'summary': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                'filter_size': 1, 'original_name': 'summary', 'display_name': 'Summary',
                'description': 'Summary of the experiment', 'is_reserved': False},
    'src_repo': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                 'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                 'filter_size': 2000, 'original_name': 'kw_src_repo', 'display_name': 'Source repository',
                 'description': 'Name of the repository this data file originated from',
                 'is_reserved': False},
    'package': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'kw_package', 'display_name': 'Package',
                'description': 'Name of the package this data file was part of', 'is_reserved': False},
    'file_location': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                      'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                      'filter_size': 2000, 'original_name': 'kw_file_location',
                      'display_name': 'File location',
                      'description': 'Unique S3 location for this data file', 'is_reserved': False},
    'dataset_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                   'filter_size': 1, 'original_name': 'dataset_id', 'display_name': 'Dataset ID',
                   'description': 'Unique ID associated with every dataset', 'is_reserved': True},
    'raw_counts_available': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': True,
                             'is_column': True, 'is_curated': False, 'is_ontology': False,
                             'is_searchable': True, 'filter_size': 1000,
                             'original_name': 'raw_counts_available',
                             'display_name': 'Raw Counts Available',
                             'description': 'Indicates whether raw counts are available for the dataset or not',
                             'is_reserved': False},
    'curated_disease': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                        'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                        'filter_size': 3000, 'original_name': 'disease', 'display_name': 'Disease',
                        'description': 'Disease associated with the dataset', 'is_reserved': False},
    'curated_drug': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                     'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                     'filter_size': 3000, 'original_name': 'kw_drug', 'display_name': 'Drug',
                     'description': 'Drugs administered to the samples belonging to the dataset',
                     'is_reserved': False},
    'curated_gene': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                     'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                     'filter_size': 3000, 'original_name': 'kw_gene', 'display_name': 'Gene',
                     'description': 'Gene studied in the dataset', 'is_reserved': False},
    'abstract': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                 'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                 'filter_size': 1, 'original_name': 'abstract', 'display_name': 'Abstract',
                 'description': 'Abstract of the publication associated with the dataset.',
                 'is_reserved': False},
    'version': {'type': 'integer', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'version', 'display_name': 'Version',
                'description': 'Version of data file', 'is_reserved': True},
    'bucket': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
               'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
               'filter_size': 2000, 'original_name': 'kw_bucket', 'display_name': 'Bucket',
               'description': 'S3 bucket in which the data file resides', 'is_reserved': False},
    'curated_tissue': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                       'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                       'filter_size': 3000, 'original_name': 'tissue', 'display_name': 'Tissue',
                       'description': 'Tissue from which the samples were derived', 'is_reserved': False},
    'dataset_source': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': True,
                       'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                       'filter_size': 1000, 'original_name': 'dataset_source', 'display_name': 'Source',
                       'description': 'Source from where the data was fetched', 'is_reserved': True},
    'data_type': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                  'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                  'filter_size': 1, 'original_name': 'kw_data_type', 'display_name': 'Data type',
                  'description': 'The type of biomolecular data captured (eg - Exome Sequencing, Transcriptomics)',
                  'is_reserved': True},
    'overall_design': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                       'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                       'filter_size': 1, 'original_name': 'overall_design',
                       'display_name': 'Overall Design',
                       'description': 'Overall design of the experiment as given by the author',
                       'is_reserved': False},
    'is_current': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                   'filter_size': 2000, 'original_name': 'is_current', 'display_name': 'Is current',
                   'description': 'Whether this is the current version of the data file or not',
                   'is_reserved': True},
    'region': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
               'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
               'filter_size': 2000, 'original_name': 'kw_region', 'display_name': 'Region',
               'description': 'Region (AWS) in which this data is located', 'is_reserved': False}}}
schemas_for_sample_level_validation = {"single_cell_rnaseq_omixatlas": {
    'gene_counts': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                    'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                    'filter_size': 1, 'original_name': 'gene_counts', 'display_name': 'Gene Counts',
                    'description': 'Number of genes detected per cell', 'is_reserved': False},
    'curated_treatment_type': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                               'is_column': True, 'is_curated': True, 'is_ontology': False,
                               'is_searchable': True, 'filter_size': 1,
                               'original_name': 'curated_treatment_type', 'display_name': 'Treatment Type',
                               'description': 'The type of treatment given to the sample',
                               'is_reserved': False},
    'curated_treatment_response': {'type': 'text', 'is_keyword': True, 'is_array': False,
                                   'is_filter': False, 'is_column': True, 'is_curated': True,
                                   'is_ontology': False, 'is_searchable': True, 'filter_size': 1,
                                   'original_name': 'curated_treatment_response',
                                   'display_name': 'Treatment Response',
                                   'description': 'This field indicates the type/extent of response on the treatment',
                                   'is_reserved': False},
    'curated_raw_cell_type': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                              'is_column': True, 'is_curated': True, 'is_ontology': False,
                              'is_searchable': True, 'filter_size': 1,
                              'original_name': 'kw_curated_raw_cell_type',
                              'display_name': 'Author Cell Type',
                              'description': 'Author cell type as mentioned in the publication associated with the dataset. ',
                              'is_reserved': False},
    'curated_donor_type': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                           'is_column': True, 'is_curated': True, 'is_ontology': False,
                           'is_searchable': True, 'filter_size': 1, 'original_name': 'curated_donor_type',
                           'display_name': 'Donor Type',
                           'description': 'The type/clinical condition of the donor ',
                           'is_reserved': False},
    'src_uri': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'kw_src_uri', 'display_name': 'Source URI',
                'description': "Unique URI derived from source data file's S3 location",
                'is_reserved': False},
    'sample_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                  'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                  'filter_size': 1, 'original_name': 'sample', 'display_name': 'Sample ID',
                  'description': 'Unique ID associated with a sample', 'is_reserved': False},
    'curated_gene_modified': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                              'is_column': True, 'is_curated': True, 'is_ontology': False,
                              'is_searchable': True, 'filter_size': 1,
                              'original_name': 'kw_curated_modified_gene', 'display_name': 'Modified Genes',
                              'description': 'Gene(s) modified in the sample under study.',
                              'is_reserved': False},
    'curated_cell_line': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                          'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                          'filter_size': 3000, 'original_name': 'kw_curated_cell_line',
                          'display_name': 'Cell Line',
                          'description': 'Cell line from which the sample was derived',
                          'is_reserved': False},
    'title': {'type': 'text', 'is_keyword': False, 'is_array': False, 'is_filter': False,
              'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
              'filter_size': 1, 'original_name': 'title', 'display_name': 'Title',
              'description': 'Title of the sample', 'is_reserved': False},
    'src_dataset_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                       'is_column': False, 'is_curated': False, 'is_ontology': False,
                       'is_searchable': False, 'filter_size': 2000, 'original_name': 'kw_src_dataset_id',
                       'display_name': 'Source dataset ID',
                       'description': 'Dataset ID of the file this data entity originated from',
                       'is_reserved': True},
    'curated_min_age': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                        'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                        'filter_size': 1, 'original_name': 'curated_min_age', 'display_name': 'Minimum Age',
                        'description': 'The lower limit of the age range of the organism from which the samples have been obtained for the study.',
                        'is_reserved': False},
    'curated_gender': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                       'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                       'filter_size': 1, 'original_name': 'curated_gender', 'display_name': 'Gender',
                       'description': 'Gender of the organism from which the sample was derived',
                       'is_reserved': False},
    'timestamp_': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                   'filter_size': 2000, 'original_name': 'kw_timestamp_', 'display_name': 'Timestamp',
                   'description': 'Unix timestamp denoting time of creation for this entry',
                   'is_reserved': False},
    'percent_mito': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                     'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                     'filter_size': 1, 'original_name': 'percent_mito', 'display_name': 'Percent Mito ',
                     'description': 'Proportion of total counts for a cell which are mitochondrial',
                     'is_reserved': False},
    'curated_treatment_name': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                               'is_column': True, 'is_curated': True, 'is_ontology': False,
                               'is_searchable': True, 'filter_size': 1,
                               'original_name': 'curated_treatment_name', 'display_name': 'Treatment Name',
                               'description': 'Name of the treatment given to the samples i.e. name of the chemical/drug/therapy',
                               'is_reserved': False},
    'curated_marker_present': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                               'is_column': True, 'is_curated': True, 'is_ontology': False,
                               'is_searchable': True, 'filter_size': 1,
                               'original_name': 'kw_curated_marker_present',
                               'display_name': 'Marker Present',
                               'description': 'Gene name/names that are differentially expressed in a cluster based on which the cell type is annotated.',
                               'is_reserved': False},
    'data_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'kw_data_id', 'display_name': 'Data ID',
                'description': 'Unique ID for this data entity on Polly', 'is_reserved': False},
    'curated_cell_type': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                          'is_column': True, 'is_curated': True, 'is_ontology': False,
                          'is_searchable': True, 'filter_size': 3000,
                          'original_name': 'kw_curated_cell_type', 'display_name': 'Cell Type',
                          'description': 'Cell type curated for the sample', 'is_reserved': False},
    'curated_donor_sample_type': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                                  'is_column': True, 'is_curated': True, 'is_ontology': False,
                                  'is_searchable': True, 'filter_size': 1,
                                  'original_name': 'curated_donor_sample_type',
                                  'display_name': 'Donor Sample Type',
                                  'description': 'The location/area from where the tumor samples are collected',
                                  'is_reserved': False},
    'clusters': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                 'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                 'filter_size': 1, 'original_name': 'clusters', 'display_name': 'Cell Type Cluster',
                 'description': 'Number of the Cell type cluster', 'is_reserved': False},
    'cell_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                'filter_size': 1, 'original_name': 'kw_column', 'display_name': 'Cell ID',
                'description': 'Unique ID associated with every cell', 'is_reserved': False},
    'curated_cell_ontology_id': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                                 'is_column': False, 'is_curated': True, 'is_ontology': False,
                                 'is_searchable': True, 'filter_size': 1,
                                 'original_name': 'curated_cell_ontology_id',
                                 'display_name': 'Cell Ontology ID',
                                 'description': 'Curated Cell Ontology ID', 'is_reserved': False},
    'src_repo': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                 'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                 'filter_size': 2000, 'original_name': 'kw_src_repo', 'display_name': 'Source repository',
                 'description': 'Name of the repository this data entity originated from',
                 'is_reserved': False},
    'id_key': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
               'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
               'filter_size': 2000, 'original_name': 'kw_id_key', 'display_name': 'ID key',
               'description': 'Name of the key that was used for creation of unique identity',
               'is_reserved': False},
    'curated_sampling_site': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                              'is_column': True, 'is_curated': True, 'is_ontology': False,
                              'is_searchable': True, 'filter_size': 1,
                              'original_name': 'curated_sampling_site', 'display_name': 'Sampling Site',
                              'description': 'The location/area from where the tumor samples are collected.',
                              'is_reserved': False},
    'curated_disease': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                        'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                        'filter_size': 3000, 'original_name': 'kw_curated_disease',
                        'display_name': 'Disease', 'description': 'Disease associated with the sample',
                        'is_reserved': False},
    'curated_drug': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                     'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                     'filter_size': 3000, 'original_name': 'kw_curated_drug', 'display_name': 'Drug',
                     'description': 'Drug administered in the sample', 'is_reserved': False},
    'curated_gene': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                     'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                     'filter_size': 3000, 'original_name': 'kw_curated_gene', 'display_name': 'Gene',
                     'description': 'Gene of interest in the sample', 'is_reserved': False},
    'curated_max_age': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                        'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                        'filter_size': 1, 'original_name': 'curated_max_age', 'display_name': 'Maximum Age',
                        'description': 'The upper limit of the age range of the organism from which the samples have been obtained for the study.',
                        'is_reserved': False},
    'version': {'type': 'integer', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                'filter_size': 2000, 'original_name': 'version', 'display_name': 'Version',
                'description': 'Version of data entity', 'is_reserved': True},
    'umi_counts': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': True, 'is_curated': False, 'is_ontology': False, 'is_searchable': True,
                   'filter_size': 1, 'original_name': 'umi_counts', 'display_name': 'UMI Counts',
                   'description': 'Absolute number of observed transcripts for a cell',
                   'is_reserved': False},
    'curated_tissue': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': True,
                       'is_column': True, 'is_curated': True, 'is_ontology': True, 'is_searchable': True,
                       'filter_size': 3000, 'original_name': 'kw_curated_tissue', 'display_name': 'Tissue',
                       'description': 'Tissue to which the sample belongs', 'is_reserved': False},
    'curated_age_unit': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                         'is_column': True, 'is_curated': True, 'is_ontology': False, 'is_searchable': True,
                         'filter_size': 1, 'original_name': 'curated_age_unit', 'display_name': 'Age Unit',
                         'description': 'The age unit of the organism from which samples have been obtained. It is years for samples from humans and weeks for samples from mice.',
                         'is_reserved': False},
    'curated_marker_absent': {'type': 'text', 'is_keyword': True, 'is_array': True, 'is_filter': False,
                              'is_column': True, 'is_curated': True, 'is_ontology': False,
                              'is_searchable': True, 'filter_size': 1,
                              'original_name': 'kw_curated_marker_absent', 'display_name': 'Marker Absent',
                              'description': 'Gene name/names that are absent in a cluster based on which the cell type is annotated.',
                              'is_reserved': False},
    'name': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False, 'is_column': False,
             'is_curated': False, 'is_ontology': False, 'is_searchable': False, 'filter_size': 2000,
             'original_name': 'kw_name', 'display_name': 'Name',
             'description': 'Name of the data entity (local to its source file)', 'is_reserved': False},
    'curated_genetic_modification_type': {'type': 'text', 'is_keyword': True, 'is_array': True,
                                          'is_filter': False, 'is_column': True, 'is_curated': True,
                                          'is_ontology': False, 'is_searchable': True, 'filter_size': 1,
                                          'original_name': 'kw_curated_genetic_mod_type',
                                          'display_name': 'Genetic Modification',
                                          'description': 'Signifies the kind of genetic modification done on the sample.',
                                          'is_reserved': False},
    'is_current': {'type': 'text', 'is_keyword': True, 'is_array': False, 'is_filter': False,
                   'is_column': False, 'is_curated': False, 'is_ontology': False, 'is_searchable': False,
                   'filter_size': 2000, 'original_name': 'is_current', 'display_name': 'Is current',
                   'description': 'Whether this is the current version of the data entity or not',
                   'is_reserved': True}}}

"""Step 4: Provide the list of dataset IDs you want to run the error 
collection on (can be all dataset IDs in an entire repo, or some selected few):"""
dataset_id_list = [
    "15_leukemic_bone_marrow_donors",
    "20200917_MGH_Broad_Villani_to_CZI",
    "3_healthy_young_and_3_healthy_old_bone_marrow_donors_Reference_sample",
    "49_years_old_male_-_Airway_Wash_1_day_post-intubation",
    "49_years_old_male_-_Airway_Wash_2_days_post-intubation"
]

"""Adjustable parameters for chunk sizes:"""
sample_metadata_query_chunk_size = 50
dataset_level_error_collection_chunk_size = 100000
sample_level_error_collection_chunk_size = 100000

CONFIG = {
    "repo_wise_run_config": {
        "run_dataset_level_validations": run_dataset_level_validations,
        "run_sample_level_validations": run_sample_level_validations,
        "sample_metadata_query_chunk_size": sample_metadata_query_chunk_size,
        "dataset_level_error_collection_chunk_size": dataset_level_error_collection_chunk_size,
        "sample_level_error_collection_chunk_size": sample_level_error_collection_chunk_size,

        "repos_for_dataset_level_validation": repos_for_dataset_level_validation,
        "schemas_for_dataset_level_validation": schemas_for_dataset_level_validation,
        "repos_for_sample_level_validation": repos_for_sample_level_validation,
        "schemas_for_sample_level_validation": schemas_for_sample_level_validation,
        "dataset_errors_table_name": "DatasetLevelErrors",
        "sample_errors_table_name": "SampleLevelErrors",
        "dataset_id_list": dataset_id_list,
        "job_details": {
            "image": "docker.polly.elucidata.io/elucidatarnd/qa_repo",
            "tag": f"{docker_image_tag}",
            "machineType": "mi5xlarge",
            "env": {
                "PROJECT_DIR": "polly_validator",
                "DB_NAME": f"{db_file_name}.db"
            },
            "name": "QA Validation Error Collection",
            "secret_env": {
                "AUTH_KEY": AUTH_KEY,
            }
        }
    },
    "last_commit_for_obo_ontology_files": "39312b6",
    "last_commit_for_compressed_ontology_files": "feff3be",
}
